@@ -4,6 +4,7 @@ import glob
 import os
 import re
 import traceback
+from datetime import datetime
 
 import dask
 import numpy as np
@@ -13,7 +14,6 @@ import xarray as xr
 import xmltodict
 import yaml
 from affine import Affine
-from datetime import datetime
 
 xpath_dict = {
     "geolocation_grid": {
@@ -1896,12 +1896,7 @@ def load_digital_number(
     tiff_files, pols = sort_list_files_and_get_pols(tiff_files)
     map_dims = {"pol": "band", "line": "y", "sample": "x"}
     if resolution is not None:
-        comment = 'resampled at "%s" with %s.%s.%s' % (
-            resolution,
-            resampling.__module__,
-            resampling.__class__.__name__,
-            resampling.name,
-        )
+        comment = f'resampled at "{resolution}" with {resampling.__module__}.{resampling.__class__.__name__}.{resampling.name}'
     else:
         comment = "read at full resolution"
 
@@ -2024,7 +2019,7 @@ def load_digital_number(
     var_name = "digital_number"
 
     dn.attrs = {
-        "comment": "%s digital number, %s" % (descr, comment),
+        "comment": f"{descr} digital number, {comment}",
         "history": yaml.safe_dump(
             {
                 var_name: get_glob(
